@@ -77,7 +77,9 @@ class _ContinuumDataset(abc.ABC):
             keep_tasks, discard_tasks
         )
 
-        new_x, new_y, new_t = x[indexes], y[indexes], t[indexes]
+        new_x, new_y, new_t = x[indexes], y[indexes], None
+        if t is not None:
+            new_t = t[indexes]
         sliced_dataset = InMemoryDataset(
             new_x, new_y, new_t,
             data_type=self.data_type
@@ -475,3 +477,16 @@ class ImageFolderDataset(_ContinuumDataset):
             y[i] = target
 
         return x, y, None
+
+
+class _AudioDataset(_ContinuumDataset):
+    @property
+    def data_type(self) -> TaskType:
+        return TaskType.AUDIO
+
+    @property
+    def transformations(self):
+        """Default transformations if nothing is provided to the scenario."""
+        def noop(x):
+            return x
+        return [noop]
