@@ -1,4 +1,4 @@
-from typing import Tuple
+from typing import Tuple, List
 
 import numpy as np
 from torchvision import datasets as torchdata
@@ -130,4 +130,4 @@ class CIFAR100(PyTorchDataset):
     def transformations(self):
         """Default transformations if nothing is provided to the scenario."""
         return [transforms.ToTensor(),
-                transforms.Normalize((0.5071, 0.4867, 0.4408), (0.2675, 0.2565, 0.2761))]
+                transforms.Normalize((0.5071, 0.4867, 0.4408), (0.2675, 0.2565, 0.2761))]
\ No newline at end of file
